@@ -1,6 +1,6 @@
-from omu_chat.const import IDENTIFIER
+from omu_chat.const import PLUGIN_ID
 
-CHAT_PERMISSION_ID = IDENTIFIER
+CHAT_PERMISSION_ID = PLUGIN_ID
 CHAT_READ_PERMISSION_ID = CHAT_PERMISSION_ID / "read"
 CHAT_WRITE_PERMISSION_ID = CHAT_PERMISSION_ID / "write"
 CHAT_SEND_PERMISSION_ID = CHAT_PERMISSION_ID / "send"
